@@ -4,10 +4,11 @@ This module defines a generic web application interface. It is a common
 protocol between web servers and web applications.
 
 The overriding design principles here are performance and generality. To
-address performance, this library is built on top of the conduit package and
-bytestring's Builder type.  The advantages of conduits over lazy IO have been
-debated elsewhere and so will not be addressed here.  However, helper functions
-like 'responseLBS' allow you to continue using lazy IO if you so desire.
+address performance, this library uses a streaming interface for request and
+response bodies, paired with bytestring's 'Builder' type.  The advantages of a
+streaming API over lazy IO have been debated elsewhere and so will not be
+addressed here.  However, helper functions like 'responseLBS' allow you to
+continue using lazy IO if you so desire.
 
 Generality is achieved by removing many variables commonly found in similar
 projects that are not universal to all servers. The goal is that the 'Request'
@@ -29,9 +30,9 @@ include:
 
 [wai-extra] <http://hackage.haskell.org/package/wai-extra>
 
-[wai-test] <http://hackage.haskell.org/package/wai-test>
-
 -}
+-- Ignore deprecations, because this module needs to use the deprecated requestBody to construct a response.
+{-# OPTIONS_GHC -fno-warn-deprecations #-}
 module Network.Wai
     (
       -- * Types
@@ -52,6 +53,7 @@ module Network.Wai
     , remoteHost
     , pathInfo
     , queryString
+    , getRequestBodyChunk
     , requestBody
     , vault
     , requestBodyLength
@@ -324,7 +326,7 @@ strictRequestBody req =
     loop id
   where
     loop front = do
-        bs <- requestBody req
+        bs <- getRequestBodyChunk req
         if B.null bs
             then return $ front LI.Empty
             else loop (front . LI.Chunk bs)
@@ -338,7 +340,7 @@ lazyRequestBody req =
     loop
   where
     loop = unsafeInterleaveIO $ do
-        bs <- requestBody req
+        bs <- getRequestBodyChunk req
         if B.null bs
             then return LI.Empty
             else do
